@@ -1,13 +1,15 @@
-require "rubygems"
-
-# Add the local gems dir if found within the app root; any dependencies loaded
-# hereafter will try to load from the local gems before loading system gems.
-if (local_gem_dir = File.join(File.dirname(__FILE__), '..', 'gems')) && $BUNDLE.nil?
-  $BUNDLE = true; Gem.clear_paths; Gem.path.unshift(local_gem_dir)
+begin
+  # Just in case the bundle was locked
+  # This shouldn't happen in a dev environment but lets be safe
+  require File.expand_path('../.bundle/environment', __FILE__)
+rescue LoadError
+  require 'rubygems'
+  require 'bundler'
+  Bundler.setup
 end
 
-require "merb-core"
 require "spec" # Satisfies Autotest and anyone else not using the Rake tasks
+require "merb-core"
 
 # this loads all plugins required in your init file so don't add them
 # here again, Merb will do it for you
@@ -17,4 +19,6 @@ Spec::Runner.configure do |config|
   config.include(Merb::Test::ViewHelper)
   config.include(Merb::Test::RouteHelper)
   config.include(Merb::Test::ControllerHelper)
+  # You don't need this if you don't use Webrat directly in your specs
+  config.include(Merb::Test::WebratHelper)
 end
