@@ -1,6 +1,6 @@
 require File.join( File.dirname(__FILE__), <%= go_up(modules.size + 1) %>, "spec_helper" )
 
-describe <%= class_name %> do
+describe <%= full_class_name %> do
 
   it "should have specs"
 
