@@ -1,4 +1,4 @@
-require File.dirname(__FILE__) + '/spec_helper'
+require 'spec_helper'
 
 describe Merb::Generators::MerbFlatGenerator do
   
@@ -9,6 +9,15 @@ describe Merb::Generators::MerbFlatGenerator do
     end
     
     it_should_behave_like "named generator"
+    it_should_behave_like "app generator"
+
+    it "should create an Gemfile" do
+      @generator.should create('/tmp/testing/Gemfile')
+    end
+
+    it "should create an bin/merb" do
+      @generator.should create('/tmp/testing/bin/merb')
+    end
     
     it "should create a number of views"
     
