@@ -1,4 +1,4 @@
-require File.dirname(__FILE__) + '/spec_helper'
+require 'spec_helper'
 
 describe Merb::Generators::MerbPluginGenerator do
   
@@ -9,7 +9,7 @@ describe Merb::Generators::MerbPluginGenerator do
     end
     
     it_should_behave_like "named generator"
-    
+
     it "should create a number of views"
     
     it "should render templates successfully" do
@@ -18,4 +18,4 @@ describe Merb::Generators::MerbPluginGenerator do
     
   end
   
-end
\ No newline at end of file
+end
