@@ -1,4 +1,4 @@
-require File.dirname(__FILE__) + '/spec_helper'
+require 'spec_helper'
 
 describe Merb::Generators::MerbStackGenerator do
 
@@ -8,12 +8,23 @@ describe Merb::Generators::MerbStackGenerator do
       @generator = Merb::Generators::MerbStackGenerator.new('/tmp', {}, 'testing')
     end
 
-    it "should create config/init.rb" do
-      @generator.should create('/tmp/testing/config/init.rb')
+    it_should_behave_like "named generator"
+    it_should_behave_like "app generator"
+
+    it "should create an Gemfile" do
+      @generator.should create('/tmp/testing/Gemfile')
     end
 
-    it "should create config/dependencies.rb" do
-      @generator.should create('/tmp/testing/config/dependencies.rb')
+    it "should create an bin/merb" do
+      @generator.should create('/tmp/testing/bin/merb')
+    end
+
+    it "should create a passenger config file" do
+      @generator.should create('/tmp/testing/config.ru')
+    end
+
+    it "should create config/init.rb" do
+      @generator.should create('/tmp/testing/config/init.rb')
     end
 
     it "should create config/database.yml" do
@@ -32,14 +43,16 @@ describe Merb::Generators::MerbStackGenerator do
       @generator.should create('/tmp/testing/.gitignore')
     end
 
-    it "should have an htaccess file" do
-      @generator.should create('/tmp/testing/public/.htaccess')
-    end
-
     it "should create a number of views"
 
     it "should render templates successfully" do
-      lambda { @generator.render! }.should_not raise_error
+      lambda do 
+        @generator.render! 
+      end.should_not raise_error
+    end
+
+    it "should create an empty lib/tasks directory" do
+      @generator.should create('/tmp/testing/lib/tasks')
     end
 
   end
