@@ -1,4 +1,4 @@
-require File.dirname(__FILE__) + '/spec_helper'
+require 'spec_helper'
 
 describe Merb::Generators::MerbVeryFlatGenerator do
   
@@ -7,6 +7,17 @@ describe Merb::Generators::MerbVeryFlatGenerator do
     before do
       @generator = Merb::Generators::MerbVeryFlatGenerator.new('/tmp', {}, 'testing')
     end
+
+    it_should_behave_like "named generator"
+    it_should_behave_like "app generator"
+
+    it "should create an Gemfile" do
+      @generator.should create('/tmp/testing/Gemfile')
+    end
+
+    it "should create an bin/merb" do
+      @generator.should create('/tmp/testing/bin/merb')
+    end
     
     it "should create a number of views"
     
@@ -16,4 +27,4 @@ describe Merb::Generators::MerbVeryFlatGenerator do
     
   end
   
-end
\ No newline at end of file
+end
